/*
 * Copyright 2016 MiLaboratory.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.milaboratory.core.alignment.batch;

import cc.redberry.primitives.Filter;
import com.milaboratory.core.sequence.Sequence;
import com.milaboratory.util.BitArray;

public interface BatchAlignerWithBaseWithFilter<S extends Sequence<S>, P, H extends AlignmentHit<S, P>>
        extends BatchAlignerWithBase<S, P, H> {
    BitArray createFilter(Filter<P> filter);

    AlignmentResult<H> align(S sequence, int from, int to, BitArray filter);

    BatchAlignerWithBaseWithFilter<S, P, H> setFloatingLeftBound(boolean floatingLeftBound);

    BatchAlignerWithBaseWithFilter<S, P, H> setFloatingRightBound(boolean floatingRightBound);
}
